@@ -70,7 +70,11 @@
 )]
 // END - Embark standard lints v0.4
 // BEGIN - Ark-specific lints
-#![warn(clippy::flat_map_option)]
+#![warn(
+    clippy::flat_map_option,
+    clippy::disallowed_method,
+    clippy::disallowed_type
+)]
 // END - Ark-specific lints
 
 // crate-specific exceptions:
